# Invis

Invis is an invisible framework which purpose is to enforce type checking of both builtins as well as user defined types at **runtime**. 
It is distributed as a single file with no extra dependencies other than the Python Standard Library (>= 3.7).

To install: `pip install invis`

A comprehensive tutorial on how to use the framework can be found
[here](https://github.com/dxflores/invis/tree/master/examples/tutorial.md)

A discussion about the project, held on reddit's algotrading subforum, can be found [here](https://www.reddit.com/r/algotrading/comments/dwrk59/a_micro_framework_to_give_you_peace_of_mind_with/)
